@@ -39,6 +39,11 @@ pub extern crate hex;
 pub extern crate async_trait;
 pub use async_trait::async_trait as worker;
 
+extern crate ockam_macro;
+pub use ockam_macro::AsyncTryClone;
+
+extern crate futures_util;
+
 pub mod compat;
 mod error;
 mod message;
@@ -91,7 +96,6 @@ pub mod traits {
         /// Try cloning a object and return an `Err` in case of failure.
         async fn async_try_clone(&self) -> Result<Self>;
     }
-
     #[async_trait]
     impl<D> AsyncTryClone for D
     where
